from . import log as log

from .SingleLog import LogLevel
from .SingleLog import Logger, DefaultLogger
